@@ -1,5 +1,3 @@
-// $Id: Service_Gestalt.cpp 96985 2013-04-11 15:50:32Z huangh $
-
 #include "ace/Svc_Conf.h"
 #include "ace/Get_Opt.h"
 #include "ace/ARGV.h"
@@ -60,7 +58,7 @@ ACE_Service_Type_Dynamic_Guard::ACE_Service_Type_Dynamic_Guard
     if (ACE::debug ())
         ACELIB_DEBUG ((LM_DEBUG,
                     ACE_TEXT ("ACE (%P|%t) STDG::<ctor>, repo=%@")
-                    ACE_TEXT(", name=%s - begining at [%d]\n"),
+                    ACE_TEXT(", name=%s - beginning at [%d]\n"),
                     &this->repo_,
                     this->name_,
                     this->repo_begin_));
@@ -134,15 +132,25 @@ Processed_Static_Svc (const ACE_Static_Svc_Descriptor *assd)
   :name_(0),
    assd_(assd)
 {
+#if defined (ACE_HAS_ALLOC_HOOKS)
+  ACE_ALLOCATOR_NORETURN (name_, static_cast<ACE_TCHAR*>(ACE_Allocator::instance()->malloc (sizeof(ACE_TCHAR) * (ACE_OS::strlen(assd->name_)+1))));
+#else
   ACE_NEW_NORETURN (name_, ACE_TCHAR[ACE_OS::strlen(assd->name_)+1]);
+#endif /* ACE_HAS_ALLOC_HOOKS */
   ACE_OS::strcpy(name_,assd->name_);
 }
 
 ACE_Service_Gestalt::Processed_Static_Svc::~Processed_Static_Svc (void)
 {
+#if defined (ACE_HAS_ALLOC_HOOKS)
+  ACE_Allocator::instance()->free(name_);
+#else
   delete [] name_;
+#endif /* ACE_HAS_ALLOC_HOOKS */
 }
 
+ACE_ALLOC_HOOK_DEFINE(ACE_Service_Gestalt::Processed_Static_Svc)
+
 void
 ACE_Service_Gestalt::intrusive_add_ref (ACE_Service_Gestalt* g)
 {
@@ -350,7 +358,7 @@ ACE_Service_Gestalt::add_processed_static_svc
   /// associates a service object with the Gestalt and makes the
   /// resource (a Service Object) local to the repository. This is but
   /// the first step in using such SO. The next is the
-  /// "initialization" step. It is typicaly done through a "static"
+  /// "initialization" step. It is typically done through a "static"
   /// service configuration directive.
   ///
   /// In contrast a "dynamic" directive, when processed through the
